SystemOrganization addCategory: #ConfigurationOfCodeTalk!

Object subclass: #ConfigurationOfCodeTalk
	instanceVariableNames: 'project'
	classVariableNames: 'LastVersionLoad'
	poolDictionaries: ''
	category: 'ConfigurationOfCodeTalk'!

!ConfigurationOfCodeTalk class methodsFor: 'private' stamp: 'tfel 10/16/2010 16:36:41.963'!
bootstrapPackage: aString from: aPath 
	| repository version |
	repository := MCHttpRepository
				location: aPath
				user: ''
				password: ''.
	repository
		versionReaderForFileNamed: aString , '.mcz'
		do: [:reader | 
			version := reader version.
			version load.
			version workingCopy repositoryGroup addRepository: repository]! !

!ConfigurationOfCodeTalk class methodsFor: 'private' stamp: 'tfel 10/16/2010 16:36:33.058'!
ensureMetacello
	"Bootstrap Gofer (if necessary), load latest mcz file for ConfigurationOfMetacello (using old 
	 Gofer API), then load the latest version of Metacello itself."

	Smalltalk at: #MetacelloProject ifAbsent: [ | error |
		"list of repositories to try, in case primary repository is not accessible"
		(Array 
			with: 'http://www.squeaksource.com/MetacelloRepository' 
			with: 'http://seaside.gemstone.com/ss/metacello') do: [:repositoryUrl |
				([
					Smalltalk at: #Gofer ifAbsent: [
					"Current version of Gofer from which to bootstrap - as of 1.0-beta.21"
						self bootstrapPackage: 'Gofer-Core-lr.115' from: repositoryUrl ].
					Smalltalk at: #Gofer ifPresent: [:goferClass | | gofer |
						gofer := goferClass new
							url: repositoryUrl;
							yourself.
						[ gofer addPackage: 'ConfigurationOfMetacello' ] on: Warning do: [:ex | ex resume ].
						gofer load ]]
							on: Error
							do: [ :ex |
								error := ex.
								Transcript 
									cr; 
									show: 'failed ensureMetacello: ';
									show: ex description printString;
									show: '...retrying'.
								"try again"
								ex return: nil ]) ~~ nil
					ifTrue: [
						"load 'default' group of Metacello"
						(Smalltalk at: #ConfigurationOfMetacello) perform: #load.
						^self ]].
		"shouldn't get here unless the load failed ... throw an error"
		self error: 'retry with alternate repository failed: ', error description printString ]! !

!ConfigurationOfCodeTalk class methodsFor: 'metacello tool support' stamp: 'tfel 10/16/2010 16:36:01.529'!
isMetacelloConfig
	"Answer true and the Metacello tools will operate on you"
	
	^true! !

!ConfigurationOfCodeTalk class methodsFor: 'metacello tool support' stamp: 'tfel 10/16/2010 16:35:52.156'!
lastMetacelloVersionLoad
	"Answer the last version loaded and the list of packages loaded for that version."

	LastVersionLoad == nil ifTrue: [ LastVersionLoad := nil -> 'default' ].
	^LastVersionLoad! !

!ConfigurationOfCodeTalk class methodsFor: 'loading' stamp: 'tfel 10/16/2010 16:34:29.897'!
load
	"self load"

	^self project stableVersion load! !

!ConfigurationOfCodeTalk class methodsFor: 'metacello tool support' stamp: 'tfel 10/16/2010 16:35:31.627'!
metacelloVersion: versionString loads: anArrayOrString
	"Stash the last version loaded and the list of packages loaded for that version. The list
	 of packages will be used by the tools when doing 'Load Package Version'"

	LastVersionLoad := versionString -> anArrayOrString! !

!ConfigurationOfCodeTalk class methodsFor: 'accessing' stamp: 'tfel 10/16/2010 16:34:43.331'!
project

	^self new project! !

!ConfigurationOfCodeTalk class methodsFor: 'unloading Metacello' stamp: 'tfel 10/16/2010 16:35:17.554'!
unloadMetacello

	Smalltalk at: #ConfigurationOfMetacello ifPresent: [:cls | cls unloadMetacello ]! !

!ConfigurationOfCodeTalk methodsFor: 'baselines' stamp: 'tfel 10/16/2010 17:10'!
baseline100: spec 
	<version: '1.0-baseline'>
	spec for: #common do: [
		spec 
			blessing: #baseline;
			repository: 'http://www.hpi.uni-potsdam.de/hirschfeld/squeaksource/codetalk'.
		spec project: 'OmniBrowser' with: [
			spec
				className: 'ConfigurationOfOmniBrowser';
				repository: 'http://www.squeaksource.com/MetacelloRepository';
				versionString: '1.2';
				loads: #( Dev )].
		
		spec project: 'SwaUtil' with: [
			spec
				className: 'ConfigurationOfSwaUtil';
				repository: 'http://www.hpi.uni-potsdam.de/hirschfeld/squeaksource/MetacelloRepository'].
		
		spec
			package: 'CodeTalk' with: [ spec requires: #('OmniBrowser' 'SwaUtil') ];
			package: 'CT-Monticello';
			package: 'CT-MarkupBrowser';
			group: 'default' with: #('CodeTalk' 'CT-Monticello' 'CT-MarkupBrowser'). ].! !

!ConfigurationOfCodeTalk methodsFor: 'baselines' stamp: 'bs 10/22/2010 16:29:51.332'!
baselineHead: spec 
	<version: 'head-baseline'>
	spec for: #common do: [
		spec 
			blessing: #baseline;
			repository: 'http://www.hpi.uni-potsdam.de/hirschfeld/squeaksource/codetalk'.
		spec project: 'OmniBrowser' with: [
			spec
				className: 'ConfigurationOfOmniBrowser';
				repository: 'http://www.squeaksource.com/MetacelloRepository';
				versionString: '1.2';
				loads: #( Dev )].
		
		spec project: 'SwaUtil' with: [
			spec
				className: 'ConfigurationOfSwaUtil';
				repository: 'http://www.hpi.uni-potsdam.de/hirschfeld/squeaksource/MetacelloRepository'].
		spec
			package: 'SWAOBExtensions' with: [spec
				repository: 'http://www.hpi.uni-potsdam.de/hirschfeld/squeaksource/SwaUtilities'].
			
		spec
			package: 'CodeTalk' with: [ spec requires: #('OmniBrowser' 'SwaUtil' 'SWAOBExtensions') ];
			package: 'CT-Monticello';
			package: 'CT-MarkupBrowser';
			group: 'default' with: #('CodeTalk' 'CT-Monticello' 'CT-MarkupBrowser'). ].! !

!ConfigurationOfCodeTalk methodsFor: 'accessing' stamp: 'tfel 10/16/2010 17:10'!
project

	^ project ifNil: [ | constructor |
		"Bootstrap Metacello if it is not already loaded"
		self class ensureMetacello.
		"Construct Metacello project"
		constructor := (Smalltalk at: #MetacelloVersionConstructor) on: self.
		project := constructor project.
		project loadType: #linear. "change to #atomic if desired"
		project ]! !

!ConfigurationOfCodeTalk methodsFor: 'versions' stamp: 'mt 10/18/2010 19:31'!
version100: spec 
        <version: '1.0' imports: #('1.0-baseline') >
        
        spec for: #common do: [
                spec blessing: #release.
                spec
                        package: 'CodeTalk' with: 'CodeTalk-mt.30';
				package: 'CT-Monticello' with: 'CT-Monticello-mt.4';
				package: 'CT-MarkupBrowser' with: 'CT-MarkupBrowser-mt.4' ].! !

!ConfigurationOfCodeTalk methodsFor: 'versions' stamp: 'bs 10/22/2010 16:31:04.125'!
versionHead: spec 
        <version: 'head' imports: #('head-baseline') >
        
        spec for: #common do: [
                spec blessing: #development ].! !
